==> forestry_1.11.2-5.3.1.39-sources.jar: forestry/arboriculture/commands/TreeSpawner.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.arboriculture.commands;

import forestry.core.commands.SpeciesNotFoundException;
import forestry.core.commands.TemplateNotFoundException;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.Vec3d;
import net.minecraft.world.gen.feature.WorldGenerator;

public class TreeSpawner implements ITreeSpawner {

	@Override
	public boolean spawn(ICommandSender sender, String treeName, EntityPlayer player) throws SpeciesNotFoundException, TemplateNotFoundException {
		Vec3d look = player.func_70040_Z();

		int x = (int) Math.round(player.field_70165_t + 3 * look.field_72450_a);
		int y = (int) Math.round(player.field_70163_u);
		int z = (int) Math.round(player.field_70161_v + 3 * look.field_72449_c);
		BlockPos pos = new BlockPos(x, y, z);

		WorldGenerator gen = TreeGenHelper.getWorldGen(treeName, player, pos);
		TreeGenHelper.generateTree(gen, player, pos);
		return true;
	}

}

==> forestry_1.11.2-5.3.4.132-sources.jar: forestry/arboriculture/commands/TreeSpawner.java <==
/*******************************************************************************
 * Copyright (c) 2011-2014 SirSengir.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the GNU Lesser Public License v3
 * which accompanies this distribution, and is available at
 * http://www.gnu.org/licenses/lgpl-3.0.txt
 *
 * Various Contributors including, but not limited to:
 * SirSengir (original work), CovertJaguar, Player, Binnie, MysteriousAges
 ******************************************************************************/
package forestry.arboriculture.commands;

import forestry.core.commands.SpeciesNotFoundException;
import forestry.core.commands.TemplateNotFoundException;
import net.minecraft.command.ICommandSender;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.util.math.BlockPos;
import net.minecraft.util.math.Vec3d;
import net.minecraft.world.gen.feature.WorldGenerator;

public class TreeSpawner implements ITreeSpawner {

	@Override
	public boolean spawn(ICommandSender sender, String treeName, EntityPlayer player) throws SpeciesNotFoundException, TemplateNotFoundException {
		Vec3d look = player.func_70040_Z();

		int x = (int) Math.round(player.field_70165_t + 3 * look.field_72450_a);
		int y = (int) Math.round(player.field_70163_u);
		int z = (int) Math.round(player.field_70161_v + 3 * look.field_72449_c);
		BlockPos pos = new BlockPos(x, y, z);

		WorldGenerator gen = TreeGenHelper.getWorldGen(treeName, player, pos);
		TreeGenHelper.generateTree(gen, player.field_70170_p, pos);
		return true;
	}

}
